==> ejc-share-impl-3.0.0-ZHHT-20241225.085614-15-sources.jar: com/ejianc/foundation/snapshort/bean/SnapshotEntity.java <==
package com.ejianc.foundation.snapshort.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.foundation.snapshort.bean.SnapshotFileEntity;
/**
 * 随手拍实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_snapshot")
public class SnapshotEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="project_id")
    private Long projectId; // 项目主键
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="description")
    private String description; // 描述
    @TableField(value="org_id")
    private Long orgId; // 组织主键
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="mark_id")
    private String markId; // 标签主键
    @TableField(value="mark_name")
    private String markName; // 标签名称
    @TableField(value="upload_user_id")
    private Long uploadUserId; // 上传人
    @TableField(value="upload_user_name")
    private String uploadUserName; // 上传人名称
    @TableField(value="upload_time")
    private Date uploadTime; // 上传时间
    

    @TableField(exist=false)
    @SubEntity(serviceName="snapshotFileService")
    private List<SnapshotFileEntity> fileList = new ArrayList<>(); // 随手拍-文件实体
    

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getMarkId() {
        return markId;
    }

    public void setMarkId(String markId) {
        this.markId = markId;
    }
    public String getMarkName() {
        return markName;
    }

    public void setMarkName(String markName) {
        this.markName = markName;
    }
    public Long getUploadUserId() {
        return uploadUserId;
    }

    public void setUploadUserId(Long uploadUserId) {
        this.uploadUserId = uploadUserId;
    }
    public String getUploadUserName() {
        return uploadUserName;
    }

    public void setUploadUserName(String uploadUserName) {
        this.uploadUserName = uploadUserName;
    }

    public Date getUploadTime() {
        return uploadTime;
    }

    public void setUploadTime(Date uploadTime) {
        this.uploadTime = uploadTime;
    }

    public List<SnapshotFileEntity> getFileList() {
        return fileList;
    }

    public void setFileList(List<SnapshotFileEntity> fileList) {
        this.fileList = fileList;
    }
}

==> ejc-share-impl-3.0.1-ZHHT-20250329.042535-89-sources.jar: com/ejianc/foundation/snapshort/bean/SnapshotEntity.java <==
package com.ejianc.foundation.snapshort.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.foundation.snapshort.bean.SnapshotFileEntity;
/**
 * 随手拍实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_snapshot")
public class SnapshotEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="project_id")
    private Long projectId; // 项目主键
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="description")
    private String description; // 描述
    @TableField(value="org_id")
    private Long orgId; // 组织主键
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="mark_id")
    private String markId; // 标签主键
    @TableField(value="mark_name")
    private String markName; // 标签名称
    @TableField(value="upload_user_id")
    private Long uploadUserId; // 上传人
    @TableField(value="upload_user_name")
    private String uploadUserName; // 上传人名称
    @TableField(value="upload_time")
    private Date uploadTime; // 上传时间
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 上级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称

    @TableField(exist=false)
    @SubEntity(serviceName="snapshotFileService")
    private List<SnapshotFileEntity> fileList = new ArrayList<>(); // 随手拍-文件实体

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    @ReferSerialTransfer(referCode = "market-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getMarkId() {
        return markId;
    }

    public void setMarkId(String markId) {
        this.markId = markId;
    }
    public String getMarkName() {
        return markName;
    }

    public void setMarkName(String markName) {
        this.markName = markName;
    }
    public Long getUploadUserId() {
        return uploadUserId;
    }

    public void setUploadUserId(Long uploadUserId) {
        this.uploadUserId = uploadUserId;
    }
    public String getUploadUserName() {
        return uploadUserName;
    }

    public void setUploadUserName(String uploadUserName) {
        this.uploadUserName = uploadUserName;
    }

    public Date getUploadTime() {
        return uploadTime;
    }

    public void setUploadTime(Date uploadTime) {
        this.uploadTime = uploadTime;
    }

    public List<SnapshotFileEntity> getFileList() {
        return fileList;
    }

    public void setFileList(List<SnapshotFileEntity> fileList) {
        this.fileList = fileList;
    }
}
